<?php
class featuredbox_cpt
{
    var $parent;

    function __construct($parent)
    {
        $this->parent = $parent;
        add_action('init', array(&$this, 'featurebox_custom_post_type'));
        add_action('add_meta_boxes', array(&$this, 'register_featuredbox_meta'));
        add_action('save_post', array(&$this, 'featuredbox_meta_save'));
    }

    public function featurebox_custom_post_type()
    {
        register_post_type("featuredbox",
            array(
                'labels' => array(
                    'name' => __('Images', $this->parent->domain),
                    'singular_name' => __('Image', $this->parent->domain),
                    'add_new' => __('Add New', $this->parent->domain),
                    'add_new_item' => __('Add New Image', $this->parent->domain),
                    'edit_item' => __('Edit Image', $this->parent->domain),
                    'new_item' => __('New Image', $this->parent->domain),
                    'all_items' => __('All Images', $this->parent->domain),
                    'view_item' => __('View Image', $this->parent->domain),
                    'search_items' => __('Search Image', $this->parent->domain),
                    'not_found' =>  __('No images found', $this->parent->domain),
                    'not_found_in_trash' => __('No images found in Trash',  $this->parent->domain),
                    'parent_item_colon' => '',
                    'menu_name' => __('Featured Box', $this->parent->domain)
                ),
                'public' => false,
                'publicly_queryable' => false,
                'can_export' => true,
                'show_ui' => true,
                '_builtin' => false,
                'capability_type' => 'post',
                'hierarchical' => false,
                'rewrite' => array('slug' => 'featuredbox'),
                'show_in_menu' => true, 
                'query_var' => 'featuredbox',
                'supports' => array( 'title', 'thumbnail')
            )
        );
  
        register_taxonomy(
            'featuredboxgroup',
            'featuredbox',
            array(
                'hierarchical' => true,
                'label' => __("Groups", $this->parent->domain),
                'singular_label' => __("Group", $this->parent->domain),
                'rewrite' => true,
                'query_var' => true,
                'public' => true,
                'rewrite' => array('slug' => 'featuredboxgroup', 'with_front' => true)
            )
        );
    }

    public function register_featuredbox_meta()
    {
        add_meta_box(
            'featuredbox-params-id',
            __('Additional parameters', $this->parent->domain),
            array(&$this, 'meta_additional_parameters'),
            'featuredbox',
            'normal',
            'high'
        );
    }
  
    public function meta_additional_parameters($post)
    {
        $data = get_post_custom( $post->ID );
        $featuredbox_meta_url = get_post_meta($post->ID, 'featuredbox_meta_url', true);
        $featuredbox_meta_image_class = get_post_meta($post->ID, 'featuredbox_meta_image_class', true);
  
        $html =
            '<table class="form-table">'.
                '<tbody>'.
                    '<tr valign="top">'.
                        '<th scope="row"><label for="featuredbox_meta_url">'.__('URL', $this->parent->domain).'</label></th>'.
                        '<td><input type="text" name="featuredbox_meta_url" id="featuredbox_meta_url" value="'.$featuredbox_meta_url.'" class="regular-text"/></td>'.
                    '</tr>'.
                    '<tr valign="top">'.
                        '<th scope="row"><label for="featuredbox_meta_image_class">'.__('Image class', $this->parent->domain).'</label></th>'.
                        '<td>'.
                          '<input type="text" name="featuredbox_meta_image_class" id="featuredbox_meta_image_class" value="'.$featuredbox_meta_image_class.'" class="regular-text"/>'.
                          '<p class="description">'.__('You can use this property to set Bootstrap image resizing class.', $this->parent->domain).'</p>'.
                        '</td>'.
                    '</tr>'.
                '</tbody>'.
            '</table>';
      
        echo $html;
    }
   
    function featuredbox_meta_save($post_id)
    {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;
        if (!current_user_can('edit_post')) return;
        
        // Save data
        if ($_POST) {
            update_post_meta($post_id, 'featuredbox_meta_url', esc_attr($_POST['featuredbox_meta_url']));
            update_post_meta($post_id, 'featuredbox_meta_image_class', esc_attr($_POST['featuredbox_meta_image_class']));
        }
    }
}
?>